@@ -62,7 +62,7 @@ public interface ISkinParam extends ISkinSimple {
 
 	public HColor getHyperlinkColor();
 
-	public boolean useUnderlineForHyperlink();
+	public UStroke useUnderlineForHyperlink();
 
 	public HColor getBackgroundColor();
 
@@ -190,4 +190,6 @@ public interface ISkinParam extends ISkinSimple {
 	public void setSvgSize(String origin, String sizeToUse);
 
 	public LengthAdjust getlengthAdjust();
+
+	public double getParamSameClassWidth();
 }
