@@ -53,6 +53,7 @@ import net.sourceforge.plantuml.activitydiagram3.gtile.GtileRepeat;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.StringBounder;
+import net.sourceforge.plantuml.graphic.VerticalAlignment;
 import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.sequencediagram.NoteType;
@@ -165,7 +166,7 @@ public class InstructionRepeat extends AbstractInstruction implements Instructio
 
 		Ftile result = factory.activity(backward, swimlaneBackward, boxStyle, Colors.empty(), null);
 		if (backwardNotes.size() > 0)
-			result = factory.addNote(result, swimlaneBackward, backwardNotes);
+			result = factory.addNote(result, swimlaneBackward, backwardNotes, VerticalAlignment.CENTER);
 
 		return result;
 	}
