@@ -67,8 +67,8 @@ public class FtileCircleStart extends AbstractFtile {
 		this.backColor = backColor;
 		this.borderColor = HColors.none();
 		this.shadowing = style.value(PName.Shadowing).asDouble();
-		this.backColor = style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(), getIHtmlColorSet());
-		this.borderColor = style.value(PName.LineColor).asColor(skinParam.getThemeStyle(), getIHtmlColorSet());
+		this.backColor = style.value(PName.BackGroundColor).asColor(getIHtmlColorSet());
+		this.borderColor = style.value(PName.LineColor).asColor(getIHtmlColorSet());
 	}
 
 	@Override
