@@ -35,11 +35,10 @@
  */
 package net.sourceforge.plantuml.asciiart;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
-import java.awt.geom.Point2D;
-
 import net.sourceforge.plantuml.FileFormat;
 import net.sourceforge.plantuml.StringUtils;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.skin.Area;
@@ -69,7 +68,7 @@ public class ComponentTextSelfArrow extends AbstractComponentText implements Arr
 		if (config.isHidden()) {
 			return;
 		}
-		final Dimension2D dimensionToUse = area.getDimensionToUse();
+		final XDimension2D dimensionToUse = area.getDimensionToUse();
 		final UmlCharArea charArea = ((UGraphicTxt) ug).getCharArea();
 		final int width = (int) dimensionToUse.getWidth();
 		final int height = (int) dimensionToUse.getHeight() - 1;
@@ -111,12 +110,12 @@ public class ComponentTextSelfArrow extends AbstractComponentText implements Arr
 		return StringUtils.getWcWidth(stringsToDisplay) + 6;
 	}
 
-	public Point2D getStartPoint(StringBounder stringBounder, Dimension2D dimensionToUse) {
-		return new Point2D.Double(0, 0);
+	public XPoint2D getStartPoint(StringBounder stringBounder, XDimension2D dimensionToUse) {
+		return new XPoint2D(0, 0);
 	}
 
-	public Point2D getEndPoint(StringBounder stringBounder, Dimension2D dimensionToUse) {
-		return new Point2D.Double(0, 0);
+	public XPoint2D getEndPoint(StringBounder stringBounder, XDimension2D dimensionToUse) {
+		return new XPoint2D(0, 0);
 	}
 
 	public double getPaddingY() {
