@@ -41,6 +41,7 @@ import java.io.IOException;
 
 import net.sourceforge.plantuml.FileUtils;
 import net.sourceforge.plantuml.brotli.BrotliInputStream;
+import net.sourceforge.plantuml.log.Logme;
 
 public class CompressionBrotli implements Compression {
 
@@ -56,7 +57,7 @@ public class CompressionBrotli implements Compression {
 			FileUtils.copyToStream(brotli, result);
 			return ByteArray.from(result.toByteArray());
 		} catch (IOException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw new NoPlantumlCompressionException(e);
 		}
 	}
