@@ -38,7 +38,6 @@ package net.sourceforge.plantuml.command;
 import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.TitledDiagram;
 import net.sourceforge.plantuml.UmlDiagram;
-import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.command.regex.Matcher2;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
@@ -66,11 +65,11 @@ public class CommandMultilinesFooter extends CommandMultilines<TitledDiagram> {
 		final Display strings = lines.toDisplay();
 		if (strings.size() > 0) {
 			HorizontalAlignment ha = HorizontalAlignment.fromString(align, HorizontalAlignment.CENTER);
-			if (UseStyle.useBetaStyle() && align == null) {
+			if (align == null)
 				ha = FontParam.FOOTER.getStyleDefinition(null)
 						.getMergedStyle(((UmlDiagram) diagram).getSkinParam().getCurrentStyleBuilder())
 						.getHorizontalAlignment();
-			}
+
 			diagram.getFooter().putDisplay(strings, ha);
 			return CommandExecutionResult.ok();
 		}
