@@ -40,6 +40,11 @@ class Elected {
 	private final String shortName;
 	private final int score;
 
+	@Override
+	public String toString() {
+		return shortName + "/" + score;
+	}
+
 	public Elected(String shortName, int score) {
 		this.shortName = shortName;
 		this.score = score;
