@@ -35,20 +35,14 @@
  */
 package net.sourceforge.plantuml.cucadiagram;
 
-
 public enum LinkHat {
 
-	NONE /*, SQUARE, CIRCLE, CIRCLE_CONNECT;
-
-	public ExtremityFactory getExtremityFactory() {
-		if (this == LinkHat.CIRCLE) {
-			return new ExtremityFactoryCircle();
-		}
-		if (this == LinkHat.CIRCLE_CONNECT) {
-			return new ExtremityFactoryCircleConnect();
-		}
-		return null;
-	}
-	*/
+	NONE /*
+			 * , SQUARE, CIRCLE, CIRCLE_CONNECT;
+			 * 
+			 * public ExtremityFactory getExtremityFactory() { if (this == LinkHat.CIRCLE) {
+			 * return new ExtremityFactoryCircle(); } if (this == LinkHat.CIRCLE_CONNECT) {
+			 * return new ExtremityFactoryCircleConnect(); } return null; }
+			 */
 
 }
