@@ -34,7 +34,6 @@
  */
 package net.sourceforge.plantuml.directdot;
 
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.command.PSystemBasicFactory;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
@@ -48,13 +47,13 @@ public class PSystemDotFactory extends PSystemBasicFactory<PSystemDot> {
 	}
 
 	@Override
-	public PSystemDot initDiagram(ThemeStyle style, UmlSource source, String startLine) {
+	public PSystemDot initDiagram(UmlSource source, String startLine) {
 		data = null;
 		return null;
 	}
 
 	@Override
-	public PSystemDot executeLine(ThemeStyle style, UmlSource source, PSystemDot system, String line) {
+	public PSystemDot executeLine(UmlSource source, PSystemDot system, String line) {
 		if (system == null && line.matches("(strict\\s+)?(di)?graph\\s+\"?[-\\w]+\"?\\s*\\{")) {
 			data = new StringBuilder(line);
 			data.append("\n");
