@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -35,10 +35,11 @@
  */
 package net.sourceforge.plantuml.flashcode;
 
+import java.awt.Color;
 import java.awt.image.BufferedImage;
 
 public interface FlashCodeUtils {
 
-	public BufferedImage exportFlashcode(String s);
+	public BufferedImage exportFlashcode(String s, Color fore, Color back);
 
 }
