@@ -42,7 +42,6 @@ import java.util.EnumSet;
 import java.util.List;
 
 import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.command.regex.Matcher2;
 import net.sourceforge.plantuml.command.regex.MyPattern;
 import net.sourceforge.plantuml.command.regex.Pattern2;
@@ -147,11 +146,11 @@ public class Splitter {
 		return s.replaceAll(htmlTag, "");
 	}
 
-	public List<HtmlCommand> getHtmlCommands(ThemeStyle themeStyle, boolean newLineAlone) {
+	public List<HtmlCommand> getHtmlCommands(boolean newLineAlone) {
 		final HtmlCommandFactory factory = new HtmlCommandFactory();
 		final List<HtmlCommand> result = new ArrayList<>();
 		for (String s : getSplittedInternal()) {
-			final HtmlCommand cmd = factory.getHtmlCommand(themeStyle, s);
+			final HtmlCommand cmd = factory.getHtmlCommand(s);
 			if (newLineAlone && cmd instanceof Text) {
 				result.addAll(splitText((Text) cmd));
 			} else {
