@@ -44,7 +44,6 @@ import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.SkinParamColors;
 import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.cucadiagram.LinkStyle;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -82,7 +81,7 @@ public class Colors {
 	private Colors() {
 	}
 
-	public Colors(ThemeStyle themeStyle, String data, HColorSet set, ColorType mainType) throws NoSuchColorException {
+	public Colors(String data, HColorSet set, ColorType mainType) throws NoSuchColorException {
 		data = StringUtils.goLowerCase(data);
 
 		for (final StringTokenizer st = new StringTokenizer(data, "#;"); st.hasMoreTokens();) {
@@ -90,7 +89,7 @@ public class Colors {
 			final int x = s.indexOf(':');
 			if (x == -1) {
 				if (s.contains(".") == false)
-					map.put(mainType, set.getColor(themeStyle, s));
+					map.put(mainType, set.getColor(s));
 
 			} else {
 				final String name = s.substring(0, x);
@@ -99,7 +98,7 @@ public class Colors {
 					this.shadowing = value.equalsIgnoreCase("true");
 				} else {
 					final ColorType key = ColorType.getType(name);
-					final HColor color = set.getColor(themeStyle, value);
+					final HColor color = set.getColor(value);
 					map.put(key, color);
 				}
 			}
