@@ -30,7 +30,6 @@
  */
 package net.sourceforge.plantuml.jsondiagram;
 
-import java.awt.geom.Point2D;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -38,6 +37,7 @@ import h.ST_Agedgeinfo_t;
 import h.ST_bezier;
 import h.ST_pointf;
 import h.ST_splines;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.ugraphic.UEllipse;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UPath;
@@ -47,13 +47,13 @@ import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public class JsonCurve {
 
-	private final List<Point2D> points = new ArrayList<>();
+	private final List<XPoint2D> points = new ArrayList<>();
 	private double maxX, maxY;
 	private final Mirror xMirror;
 	private final double veryFirstLine;
 
-	private final Point2D sp;
-	private final Point2D ep;
+	private final XPoint2D sp;
+	private final XPoint2D ep;
 
 	public JsonCurve(ST_Agedgeinfo_t data, Mirror xMirror, double veryFirstLine) {
 		this.veryFirstLine = veryFirstLine;
@@ -64,7 +64,7 @@ public class JsonCurve {
 		}
 		final ST_bezier beziers = splines.list.get__(0);
 		for (int i = 0; i < beziers.size; i++) {
-			final Point2D pt = getPoint(splines, i);
+			final XPoint2D pt = getPoint(splines, i);
 			maxX = Math.max(maxX, pt.getX());
 			maxY = Math.max(maxY, pt.getY());
 			points.add(pt);
@@ -73,20 +73,20 @@ public class JsonCurve {
 		if (beziers.sp.x == 0 && beziers.sp.y == 0) {
 			sp = null;
 		} else {
-			sp = new Point2D.Double(beziers.sp.x, beziers.sp.y);
+			sp = new XPoint2D(beziers.sp.x, beziers.sp.y);
 		}
 		if (beziers.ep.x == 0 && beziers.ep.y == 0) {
 			ep = null;
 		} else {
-			ep = new Point2D.Double(beziers.ep.x, beziers.ep.y);
+			ep = new XPoint2D(beziers.ep.x, beziers.ep.y);
 		}
 
 	}
 
-	private Point2D getPoint(ST_splines splines, int i) {
+	private XPoint2D getPoint(ST_splines splines, int i) {
 		final ST_bezier beziers = splines.list.get__(0);
 		final ST_pointf pt = beziers.list.get__(i);
-		return new Point2D.Double(pt.x, pt.y);
+		return new XPoint2D(pt.x, pt.y);
 	}
 
 	public void drawCurve(HColor color, UGraphic ug) {
@@ -96,16 +96,16 @@ public class JsonCurve {
 		path.lineTo(xMirror.invAndXYSwitch(points.get(0)));
 
 		for (int i = 1; i < points.size(); i += 3) {
-			final Point2D pt2 = xMirror.invAndXYSwitch(points.get(i));
-			final Point2D pt3 = xMirror.invAndXYSwitch(points.get(i + 1));
-			final Point2D pt4 = xMirror.invAndXYSwitch(points.get(i + 2));
+			final XPoint2D pt2 = xMirror.invAndXYSwitch(points.get(i));
+			final XPoint2D pt3 = xMirror.invAndXYSwitch(points.get(i + 1));
+			final XPoint2D pt4 = xMirror.invAndXYSwitch(points.get(i + 2));
 			path.cubicTo(pt2, pt3, pt4);
 		}
 		ug.draw(path);
 
 		if (ep != null) {
-			final Point2D last = xMirror.invAndXYSwitch(points.get(points.size() - 1));
-			final Point2D trueEp = xMirror.invAndXYSwitch(ep);
+			final XPoint2D last = xMirror.invAndXYSwitch(points.get(points.size() - 1));
+			final XPoint2D trueEp = xMirror.invAndXYSwitch(ep);
 			new Arrow(last, trueEp).drawArrow(ug.apply(color.bg()));
 		}
 	}
@@ -116,17 +116,17 @@ public class JsonCurve {
 		ug.apply(new UStroke()).draw(new UEllipse(2 * size, 2 * size));
 	}
 
-	private Point2D getVeryFirst() {
+	private XPoint2D getVeryFirst() {
 		return supp(xMirror.invAndXYSwitch(points.get(0)), xMirror.invAndXYSwitch(points.get(1)), veryFirstLine);
 
 	}
 
-	private static Point2D supp(Point2D center, Point2D direction, double len) {
+	private static XPoint2D supp(XPoint2D center, XPoint2D direction, double len) {
 		final double full = center.distance(direction);
 		final double dx = (center.getX() - direction.getX()) / full;
 		final double dy = (center.getY() - direction.getY()) / full;
 
-		return new Point2D.Double(center.getX() + dx * len, center.getY() + dy * len);
+		return new XPoint2D(center.getX() + dx * len, center.getY() + dy * len);
 
 	}
 
