@@ -35,10 +35,8 @@
  */
 package net.sourceforge.plantuml.salt.element;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
-import java.awt.geom.Point2D;
-
-import net.sourceforge.plantuml.Dimension2DDouble;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
@@ -72,16 +70,16 @@ public class ElementBorder extends AbstractElement {
 		this.center = center;
 	}
 
-	public void drawU(UGraphic ug, int zIndex, Dimension2D dimToUse) {
+	public void drawU(UGraphic ug, int zIndex, XDimension2D dimToUse) {
 		final StringBounder stringBounder = ug.getStringBounder();
-		final Dimension2D dimNorth = north.getPreferredDimension(stringBounder, 0, 0);
-		final Dimension2D dimSouth = south.getPreferredDimension(stringBounder, 0, 0);
-		final Dimension2D dimEast = east.getPreferredDimension(stringBounder, 0, 0);
-		final Dimension2D dimWest = west.getPreferredDimension(stringBounder, 0, 0);
-		final Point2D pA = new Point2D.Double(dimWest.getWidth(), dimNorth.getHeight());
-		final Point2D pB = new Point2D.Double(dimToUse.getWidth() - dimEast.getWidth(), dimNorth.getHeight());
-		final Point2D pC = new Point2D.Double(dimWest.getWidth(), dimToUse.getHeight() - dimSouth.getHeight());
-		// final Point2D pD = new Point2D.Double(dimToUse.getWidth() - dimEast.getWidth(), dimToUse.getHeight()
+		final XDimension2D dimNorth = north.getPreferredDimension(stringBounder, 0, 0);
+		final XDimension2D dimSouth = south.getPreferredDimension(stringBounder, 0, 0);
+		final XDimension2D dimEast = east.getPreferredDimension(stringBounder, 0, 0);
+		final XDimension2D dimWest = west.getPreferredDimension(stringBounder, 0, 0);
+		final XPoint2D pA = new XPoint2D(dimWest.getWidth(), dimNorth.getHeight());
+		final XPoint2D pB = new XPoint2D(dimToUse.getWidth() - dimEast.getWidth(), dimNorth.getHeight());
+		final XPoint2D pC = new XPoint2D(dimWest.getWidth(), dimToUse.getHeight() - dimSouth.getHeight());
+		// final XPoint2D pD = new XPoint2D(dimToUse.getWidth() - dimEast.getWidth(), dimToUse.getHeight()
 		// - dimSouth.getHeight());
 
 		north.drawU(ug, zIndex, dimToUse);
@@ -91,17 +89,17 @@ public class ElementBorder extends AbstractElement {
 		center.drawU(ug.apply(new UTranslate(pA.getX(), pA.getY())), zIndex, dimToUse);
 	}
 
-	public Dimension2D getPreferredDimension(StringBounder stringBounder, double x, double y) {
-		final Dimension2D dimNorth = north.getPreferredDimension(stringBounder, x, y);
-		final Dimension2D dimSouth = south.getPreferredDimension(stringBounder, x, y);
-		final Dimension2D dimEast = east.getPreferredDimension(stringBounder, x, y);
-		final Dimension2D dimWest = west.getPreferredDimension(stringBounder, x, y);
-		final Dimension2D dimCenter = center.getPreferredDimension(stringBounder, x, y);
+	public XDimension2D getPreferredDimension(StringBounder stringBounder, double x, double y) {
+		final XDimension2D dimNorth = north.getPreferredDimension(stringBounder, x, y);
+		final XDimension2D dimSouth = south.getPreferredDimension(stringBounder, x, y);
+		final XDimension2D dimEast = east.getPreferredDimension(stringBounder, x, y);
+		final XDimension2D dimWest = west.getPreferredDimension(stringBounder, x, y);
+		final XDimension2D dimCenter = center.getPreferredDimension(stringBounder, x, y);
 		final double width = MathUtils.max(dimNorth.getWidth(), dimSouth.getWidth(),
 				dimWest.getWidth() + dimCenter.getWidth() + dimEast.getWidth());
 		final double height = dimNorth.getHeight()
 				+ MathUtils.max(dimWest.getHeight(), dimCenter.getHeight(), dimEast.getHeight()) + dimSouth.getHeight();
-		return new Dimension2DDouble(width, height);
+		return new XDimension2D(width, height);
 	}
 
 }
