@@ -41,10 +41,21 @@ import net.sourceforge.plantuml.sequencediagram.Event;
 
 public abstract class AbstractTile extends CommonTile implements Tile {
 
+	public AbstractTile(StringBounder stringBounder, YGauge currentY) {
+		super(stringBounder);
+		if (YGauge.USE_ME)
+			System.err.println("CREATING " + getClass());
+	}
+
 	public AbstractTile(StringBounder stringBounder) {
 		super(stringBounder);
 	}
 
+	@Override
+	public YGauge getYGauge() {
+		throw new UnsupportedOperationException(getClass().toString());
+	}
+
 	public double getContactPointRelative() {
 		return -1;
 	}
@@ -59,9 +70,9 @@ public abstract class AbstractTile extends CommonTile implements Tile {
 		final Event event = this.getEvent();
 		if (event instanceof AbstractMessage) {
 			final AbstractMessage msg = (AbstractMessage) event;
-			if (anchor.equals(msg.getAnchor())) {
+			if (anchor.equals(msg.getAnchor()))
 				return true;
-			}
+
 		}
 		return false;
 	}
