@@ -61,6 +61,7 @@ public class CommunicationTileSelf extends AbstractTile {
 	private final Rose skin;
 	private final ISkinParam skinParam;
 	private final LivingSpaces livingSpaces;
+	private final YGauge yGauge;
 
 	public Event getEvent() {
 		return message;
@@ -72,24 +73,20 @@ public class CommunicationTileSelf extends AbstractTile {
 	}
 
 	public CommunicationTileSelf(StringBounder stringBounder, LivingSpace livingSpace1, Message message, Rose skin,
-			ISkinParam skinParam, LivingSpaces livingSpaces) {
-		super(stringBounder);
+			ISkinParam skinParam, LivingSpaces livingSpaces, YGauge currentY) {
+		super(stringBounder, currentY);
 		this.livingSpace1 = livingSpace1;
 		this.livingSpaces = livingSpaces;
 		this.message = message;
 		this.skin = skin;
 		this.skinParam = skinParam;
+		this.yGauge = YGauge.create(currentY.getMax(), getPreferredHeight());
 	}
 
-	// private boolean isReverse(StringBounder stringBounder) {
-	// final Real point1 = livingSpace1.getPosC(stringBounder);
-	// final Real point2 = livingSpace2.getPosC(stringBounder);
-	// if (point1.getCurrentValue() > point2.getCurrentValue()) {
-	// return true;
-	// }
-	// return false;
-	//
-	// }
+	@Override
+	public YGauge getYGauge() {
+		return yGauge;
+	}
 
 	private ArrowComponent getComponent(StringBounder stringBounder) {
 		ArrowConfiguration arrowConfiguration = message.getArrowConfiguration();
@@ -100,23 +97,25 @@ public class CommunicationTileSelf extends AbstractTile {
 	}
 
 	@Override
-	final protected void callbackY_internal(double y) {
+	final protected void callbackY_internal(TimeHook y) {
+		super.callbackY_internal(y);
 		final ArrowComponent comp = getComponent(getStringBounder());
 		final XDimension2D dim = comp.getPreferredDimension(getStringBounder());
 		final XPoint2D p1 = comp.getStartPoint(getStringBounder(), dim);
 		final XPoint2D p2 = comp.getEndPoint(getStringBounder(), dim);
 
-		if (message.isActivate()) {
-			livingSpace1.addStepForLivebox(getEvent(), y + p2.getY());
-		} else if (message.isDeactivate()) {
-			livingSpace1.addStepForLivebox(getEvent(), y + p1.getY());
-		} else if (message.isDestroy()) {
-			livingSpace1.addStepForLivebox(getEvent(), y + p2.getY());
-		}
+		if (message.isActivate())
+			livingSpace1.addStepForLivebox(getEvent(), y.getValue() + p2.getY());
+		else if (message.isDeactivate())
+			livingSpace1.addStepForLivebox(getEvent(), y.getValue() + p1.getY());
+		else if (message.isDestroy())
+			livingSpace1.addStepForLivebox(getEvent(), y.getValue() + p2.getY());
 
 	}
 
 	public void drawU(UGraphic ug) {
+		if (YGauge.USE_ME)
+			ug = ug.apply(UTranslate.dy(getYGauge().getMin().getCurrentValue()));
 		final StringBounder stringBounder = ug.getStringBounder();
 		final Component comp = getComponent(stringBounder);
 		final XDimension2D dim = comp.getPreferredDimension(stringBounder);
