@@ -38,7 +38,7 @@ package net.sourceforge.plantuml.sequencediagram.teoz;
 import java.io.IOException;
 import java.io.OutputStream;
 
-import net.sourceforge.plantuml.AnnotatedWorker;
+import net.sourceforge.plantuml.AnnotatedBuilder;
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.ISkinParam;
@@ -74,7 +74,8 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 	private final SequenceDiagram diagram;
 	private final FileFormatOption fileFormatOption;
 	private final Rose skin;
-	private final AnnotatedWorker annotatedWorker;
+	private final AnnotatedBuilder annotatedBuilder;
+
 	private final int index;
 
 	public SequenceDiagramFileMakerTeoz(SequenceDiagram diagram, Rose skin, FileFormatOption fileFormatOption,
@@ -87,13 +88,13 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 		this.body = new PlayingSpaceWithParticipants(createMainTile());
 		this.footer = getFooterOrHeader(FontParam.FOOTER);
 		this.header = getFooterOrHeader(FontParam.HEADER);
-		this.annotatedWorker = new AnnotatedWorker(diagram, diagram.getSkinParam(), stringBounder);
+		this.annotatedBuilder = new AnnotatedBuilder(diagram, diagram.getSkinParam(), stringBounder);
 
 		this.min1 = body.getMinX(stringBounder);
 
 		this.title = getTitle();
 		this.legend = getLegend();
-		this.caption = annotatedWorker.getCaption();
+		this.caption = annotatedBuilder.getCaption();
 
 		this.heightEnglober1 = dolls.getOffsetForEnglobers(stringBounder);
 		this.heightEnglober2 = heightEnglober1 == 0 ? 0 : 10;
@@ -107,7 +108,7 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 				+ header.calculateDimension(stringBounder).getHeight()
 				+ legend.calculateDimension(stringBounder).getHeight()
 				+ caption.calculateDimension(stringBounder).getHeight()
-				+ footer.calculateDimension(stringBounder).getHeight() + (annotatedWorker.hasMainFrame() ? 10 : 0);
+				+ footer.calculateDimension(stringBounder).getHeight() + (annotatedBuilder.hasMainFrame() ? 10 : 0);
 		this.dimTotal = new XDimension2D(totalWidth, totalHeight);
 	}
 
@@ -175,24 +176,28 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 	}
 
 	private PlayingSpace createMainTile() {
-		final RealOrigin origin = RealUtils.createOrigin();
-		Real currentPos = origin.addAtLeast(0);
+		final RealOrigin xorigin = RealUtils.createOrigin();
+		Real xcurrent = xorigin.addAtLeast(0);
+		final RealOrigin yorigin = RealUtils.createOrigin();
 		for (Participant p : diagram.participants()) {
-			final LivingSpace livingSpace = new LivingSpace(p, diagram.getEnglober(p), skin, getSkinParam(), currentPos,
+			final LivingSpace livingSpace = new LivingSpace(p, diagram.getEnglober(p), skin, getSkinParam(), xcurrent,
 					diagram.events());
 			livingSpaces.put(p, livingSpace);
-			currentPos = livingSpace.getPosD(stringBounder).addAtLeast(0);
+			xcurrent = livingSpace.getPosD(stringBounder).addAtLeast(0);
 		}
 
 		final TileArguments tileArguments = new TileArguments(stringBounder, livingSpaces, skin, diagram.getSkinParam(),
-				origin);
+				xorigin, yorigin);
 
 		this.dolls = new Dolls(tileArguments);
 		final PlayingSpace mainTile = new PlayingSpace(diagram, dolls, tileArguments);
 		this.livingSpaces.addConstraints(stringBounder);
 		mainTile.addConstraints();
 		this.dolls.addConstraints(stringBounder);
-		origin.compileNow();
+		xorigin.compileNow();
+		if (YGauge.USE_ME)
+			System.err.println("COMPILING Y");
+		yorigin.compileNow();
 		tileArguments.setBordered(mainTile);
 		return mainTile;
 	}
@@ -264,8 +269,8 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 		}
 
 		ug = ug.apply(UTranslate.dy(heightEnglober1));
-		final TextBlock bodyFramed = annotatedWorker.addFrame(body);
-		printAligned(ug.apply(UTranslate.dx((annotatedWorker.hasMainFrame() ? 4 : 0))), HorizontalAlignment.CENTER,
+		final TextBlock bodyFramed = annotatedBuilder.decoreWithFrame(body);
+		printAligned(ug.apply(UTranslate.dx((annotatedBuilder.hasMainFrame() ? 4 : 0))), HorizontalAlignment.CENTER,
 				bodyFramed);
 		ug = goDown(ug, bodyFramed);
 		ug = ug.apply(UTranslate.dy(heightEnglober2));
