@@ -35,8 +35,7 @@
  */
 package net.sourceforge.plantuml.skin;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.graphic.AbstractTextBlock;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.SymbolContext;
@@ -104,7 +103,7 @@ public class ActorAwesome extends AbstractTextBlock implements TextBlock {
 		return headDiam + bodyHeight + thickness() * 2;
 	}
 
-	public Dimension2D calculateDimension(StringBounder stringBounder) {
-		return new Dimension2DDouble(getPreferredWidth(), getPreferredHeight());
+	public XDimension2D calculateDimension(StringBounder stringBounder) {
+		return new XDimension2D(getPreferredWidth(), getPreferredHeight());
 	}
 }
\ No newline at end of file
