@@ -56,7 +56,7 @@ public enum ComponentType implements Styleable {
 	DELAY_LINE, PARTICIPANT_LINE, CONTINUE_LINE,
 
 	//
-	GROUPING_ELSE, GROUPING_HEADER, GROUPING_SPACE,
+	GROUPING_ELSE_LEGACY, GROUPING_ELSE_TEOZ, GROUPING_HEADER, GROUPING_SPACE,
 	//
 	NEWPAGE, NOTE, NOTE_HEXAGONAL, NOTE_BOX, DIVIDER, REFERENCE, ENGLOBER,
 
