@@ -40,8 +40,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.Objects;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.graphic.AbstractTextBlock;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
@@ -52,7 +51,6 @@ import net.sourceforge.plantuml.ugraphic.PixelImage;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UImage;
 import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapperMonochrome;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public class SpriteImage implements Sprite {
@@ -63,20 +61,21 @@ public class SpriteImage implements Sprite {
 		this.img = new UImage(new PixelImage(Objects.requireNonNull(img), AffineTransformType.TYPE_BILINEAR));
 	}
 
-	public TextBlock asTextBlock(final HColor color, final double scale, final ColorMapper colorMapper) {
+	public TextBlock asTextBlock(final HColor color, final double scale) {
 		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
-				if (colorMapper instanceof ColorMapperMonochrome)
+				final ColorMapper colorMapper = ug.getColorMapper();
+				if (colorMapper == ColorMapper.MONOCHROME)
 					ug.draw(img.monochrome().scale(scale));
 				else if (color == null)
 					ug.draw(img.scale(scale));
 				else
-					ug.draw(img.muteColor(colorMapper.toColor(color)).scale(scale));
+					ug.draw(img.muteColor(color.toColor(colorMapper)).scale(scale));
 			}
 
-			public Dimension2D calculateDimension(StringBounder stringBounder) {
-				return new Dimension2DDouble(img.getWidth() * scale, img.getHeight() * scale);
+			public XDimension2D calculateDimension(StringBounder stringBounder) {
+				return new XDimension2D(img.getWidth() * scale, img.getHeight() * scale);
 			}
 		};
 	}
