@@ -37,14 +37,11 @@ package net.sourceforge.plantuml.svek;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 
-import java.awt.geom.Point2D;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.HashSet;
 import java.util.List;
-import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -52,6 +49,8 @@ import net.sourceforge.plantuml.BaseFile;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.UmlDiagramType;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
+import net.sourceforge.plantuml.command.Position;
 import net.sourceforge.plantuml.cucadiagram.CucaDiagram;
 import net.sourceforge.plantuml.cucadiagram.IGroup;
 import net.sourceforge.plantuml.cucadiagram.Rankdir;
@@ -64,7 +63,6 @@ import net.sourceforge.plantuml.cucadiagram.dot.GraphvizVersions;
 import net.sourceforge.plantuml.cucadiagram.dot.ProcessState;
 import net.sourceforge.plantuml.cucadiagram.entity.EntityFactory;
 import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.posimo.Moveable;
 import net.sourceforge.plantuml.security.SFile;
 import net.sourceforge.plantuml.vizjs.GraphvizJs;
@@ -74,8 +72,6 @@ public class DotStringFactory implements Moveable {
 
 	private final Bibliotekon bibliotekon = new Bibliotekon();
 
-	final private Set<String> rankMin = new HashSet<>();
-
 	private final ColorSequence colorSequence;
 	private final Cluster root;
 
@@ -94,7 +90,8 @@ public class DotStringFactory implements Moveable {
 
 		this.colorSequence = new ColorSequence();
 		this.stringBounder = stringBounder;
-		this.root = new Cluster(colorSequence, skinParam, dotData.getRootGroup());
+		this.root = new Cluster(dotData.getEntityFactory().getDiagram(), colorSequence, skinParam,
+				dotData.getRootGroup());
 		this.current = root;
 	}
 
@@ -105,7 +102,7 @@ public class DotStringFactory implements Moveable {
 
 		this.colorSequence = new ColorSequence();
 		this.stringBounder = stringBounder;
-		this.root = new Cluster(colorSequence, skinParam, diagram.getEntityFactory().getRootGroup());
+		this.root = new Cluster(diagram, colorSequence, skinParam, diagram.getEntityFactory().getRootGroup());
 		this.current = root;
 	}
 
@@ -113,19 +110,6 @@ public class DotStringFactory implements Moveable {
 		current.addNode(node);
 	}
 
-	private void printMinRanking(StringBuilder sb) {
-		if (rankMin.size() == 0)
-			return;
-
-		sb.append("{ rank = min;");
-		for (String id : rankMin) {
-			sb.append(id);
-			sb.append(";");
-		}
-		sb.append("}");
-
-	}
-
 	private double getHorizontalDzeta() {
 		double max = 0;
 		for (SvekLine l : bibliotekon.allLines()) {
@@ -145,6 +129,8 @@ public class DotStringFactory implements Moveable {
 				max = c;
 
 		}
+		if (root.diagram.getPragma().useKermor())
+			return max / 100;
 		return max / 10;
 	}
 
@@ -173,13 +159,13 @@ public class DotStringFactory implements Moveable {
 		SvekUtils.println(sb);
 
 		for (String s : dotStrings) {
-			if (s.startsWith("ranksep")) {
+			if (s.startsWith("ranksep"))
 				sb.append("ranksep=" + ranksepInches + ";");
-			} else if (s.startsWith("nodesep")) {
+			else if (s.startsWith("nodesep"))
 				sb.append("nodesep=" + nodesepInches + ";");
-			} else {
+			else
 				sb.append(s);
-			}
+
 			SvekUtils.println(sb);
 		}
 		// sb.append("newrank=true;");
@@ -210,16 +196,28 @@ public class DotStringFactory implements Moveable {
 
 		manageMinMaxCluster(sb);
 
-		root.printCluster1(sb, bibliotekon.allLines(), stringBounder);
-		for (SvekLine line : bibliotekon.lines0())
-			line.appendLine(getGraphvizVersion(), sb, dotMode, dotSplines);
+		if (root.diagram.getPragma().useKermor()) {
+			for (SvekLine line : bibliotekon.lines0())
+				line.appendLine(getGraphvizVersion(), sb, dotMode, dotSplines);
+			for (SvekLine line : bibliotekon.lines1())
+				line.appendLine(getGraphvizVersion(), sb, dotMode, dotSplines);
 
-		root.fillRankMin(rankMin);
-		root.printCluster2(sb, bibliotekon.allLines(), stringBounder, dotMode, getGraphvizVersion(), umlDiagramType);
-		printMinRanking(sb);
+			root.printCluster3_forKermor(sb, bibliotekon.allLines(), stringBounder, dotMode, getGraphvizVersion(),
+					umlDiagramType);
 
-		for (SvekLine line : bibliotekon.lines1())
-			line.appendLine(getGraphvizVersion(), sb, dotMode, dotSplines);
+		} else {
+			root.printCluster1(sb, bibliotekon.allLines(), stringBounder);
+
+			for (SvekLine line : bibliotekon.lines0())
+				line.appendLine(getGraphvizVersion(), sb, dotMode, dotSplines);
+
+			root.printCluster2(sb, bibliotekon.allLines(), stringBounder, dotMode, getGraphvizVersion(),
+					umlDiagramType);
+
+			for (SvekLine line : bibliotekon.lines1())
+				line.appendLine(getGraphvizVersion(), sb, dotMode, dotSplines);
+
+		}
 
 		SvekUtils.println(sb);
 		sb.append("}");
@@ -267,6 +265,8 @@ public class DotStringFactory implements Moveable {
 			// return 29;
 			return 40;
 		}
+		if (root.diagram.getPragma().useKermor())
+			return 40;
 		return 60;
 	}
 
@@ -309,9 +309,9 @@ public class DotStringFactory implements Moveable {
 		try {
 			final ProcessState state = graphviz.createFile3(baos);
 			baos.close();
-			if (state.differs(ProcessState.TERMINATED_OK())) {
+			if (state.differs(ProcessState.TERMINATED_OK()))
 				throw new IllegalStateException("Timeout4 " + state, state.getCause());
-			}
+
 		} catch (GraphvizJsRuntimeException e) {
 			System.err.println("GraphvizJsRuntimeException");
 			graphvizVersion = GraphvizJs.getGraphvizVersion(true);
@@ -367,17 +367,14 @@ public class DotStringFactory implements Moveable {
 			int idx = svg.indexOf("<title>" + node.getUid() + "</title>");
 			if (node.getType() == ShapeType.RECTANGLE || node.getType() == ShapeType.RECTANGLE_HTML_FOR_PORTS
 					|| node.getType() == ShapeType.RECTANGLE_WITH_CIRCLE_INSIDE || node.getType() == ShapeType.FOLDER
-					|| node.getType() == ShapeType.DIAMOND) {
-				final List<Point2D.Double> points = svgResult.substring(idx).extractList(SvgResult.POINTS_EQUALS);
-				final double minY = SvekUtils.getMinY(points);
-				final double overscanX = node.getOverscanX(stringBounder);
-				final double minX = SvekUtils.getMinX(points);
-//				corner1.manage(minX - overscanX, minY);
-				node.moveSvek(minX, minY);
+					|| node.getType() == ShapeType.DIAMOND || node.getType() == ShapeType.RECTANGLE_PORT) {
+				final List<XPoint2D> points = svgResult.substring(idx).extractList(SvgResult.POINTS_EQUALS);
+				final XPoint2D min = SvekUtils.getMinXY(points);
+				node.moveSvek(min.getX(), min.getY());
 			} else if (node.getType() == ShapeType.ROUND_RECTANGLE) {
 				final int idx2 = svg.indexOf("d=\"", idx + 1);
 				idx = svg.indexOf("points=\"", idx + 1);
-				final List<Point2D.Double> points;
+				final List<XPoint2D> points;
 				if (idx2 != -1 && (idx == -1 || idx2 < idx)) {
 					// GraphViz 2.30
 					points = svgResult.substring(idx2).extractList(SvgResult.D_EQUALS);
@@ -388,21 +385,17 @@ public class DotStringFactory implements Moveable {
 						points.addAll(svgResult.substring(idx).extractList(SvgResult.POINTS_EQUALS));
 					}
 				}
-				final double minX = SvekUtils.getMinX(points);
-				final double minY = SvekUtils.getMinY(points);
-//				corner1.manage(minX, minY);
-				node.moveSvek(minX, minY);
+				final XPoint2D min = SvekUtils.getMinXY(points);
+				node.moveSvek(min.getX(), min.getY());
 			} else if (node.getType() == ShapeType.OCTAGON || node.getType() == ShapeType.HEXAGON) {
 				idx = svg.indexOf("points=\"", idx + 1);
 				final int starting = idx;
-				final List<Point2D.Double> points = svgResult.substring(starting).extractList(SvgResult.POINTS_EQUALS);
-				final double minX = SvekUtils.getMinX(points);
-				final double minY = SvekUtils.getMinY(points);
+				final List<XPoint2D> points = svgResult.substring(starting).extractList(SvgResult.POINTS_EQUALS);
+				final XPoint2D min = SvekUtils.getMinXY(points);
 				// corner1.manage(minX, minY);
-				node.moveSvek(minX, minY);
-				node.setPolygon(minX, minY, points);
-			} else if (node.getType() == ShapeType.CIRCLE || node.getType() == ShapeType.CIRCLE_IN_RECT
-					|| node.getType() == ShapeType.OVAL) {
+				node.moveSvek(min.getX(), min.getY());
+				node.setPolygon(min.getX(), min.getY(), points);
+			} else if (node.getType() == ShapeType.CIRCLE || node.getType() == ShapeType.OVAL) {
 				final double cx = SvekUtils.getValue(svg, idx, "cx");
 				final double cy = SvekUtils.getValue(svg, idx, "cy") + fullHeight;
 				final double rx = SvekUtils.getValue(svg, idx, "rx");
@@ -422,24 +415,31 @@ public class DotStringFactory implements Moveable {
 			}
 			int idx = getClusterIndex(svg, cluster.getColor());
 			final int starting = idx;
-			final List<Point2D.Double> points = svgResult.substring(starting).extractList(SvgResult.POINTS_EQUALS);
-			final double minX = SvekUtils.getMinX(points);
-			final double minY = SvekUtils.getMinY(points);
-			final double maxX = SvekUtils.getMaxX(points);
-			final double maxY = SvekUtils.getMaxY(points);
-			cluster.setPosition(minX, minY, maxX, maxY);
-			// corner1.manage(minX, minY);
+			final List<XPoint2D> points = svgResult.substring(starting).extractList(SvgResult.POINTS_EQUALS);
+			final XPoint2D min = SvekUtils.getMinXY(points);
+			final XPoint2D max = SvekUtils.getMaxXY(points);
+			cluster.setPosition(min, max);
 
 			if (cluster.getTitleAndAttributeWidth() == 0 || cluster.getTitleAndAttributeHeight() == 0)
 				continue;
 
 			idx = getClusterIndex(svg, cluster.getTitleColor());
-			final int starting1 = idx;
-			final List<Point2D.Double> pointsTitle = svgResult.substring(starting1)
-					.extractList(SvgResult.POINTS_EQUALS);
-			final double minXtitle = SvekUtils.getMinX(pointsTitle);
-			final double minYtitle = SvekUtils.getMinY(pointsTitle);
-			cluster.setTitlePosition(minXtitle, minYtitle);
+			final List<XPoint2D> pointsTitle = svgResult.substring(idx).extractList(SvgResult.POINTS_EQUALS);
+			cluster.setTitlePosition(SvekUtils.getMinXY(pointsTitle));
+
+			if (root.diagram.getPragma().useKermor()) {
+				if (cluster.getGroup().getNotes(Position.TOP).size() > 0) {
+					final List<XPoint2D> noteUp = svgResult.substring(getClusterIndex(svg, cluster.getColorNoteTop()))
+							.extractList(SvgResult.POINTS_EQUALS);
+					cluster.setNoteTopPosition(SvekUtils.getMinXY(noteUp));
+				}
+				if (cluster.getGroup().getNotes(Position.BOTTOM).size() > 0) {
+					final List<XPoint2D> noteBottom = svgResult
+							.substring(getClusterIndex(svg, cluster.getColorNoteBottom()))
+							.extractList(SvgResult.POINTS_EQUALS);
+					cluster.setNoteBottomPosition(SvekUtils.getMinXY(noteBottom));
+				}
+			}
 		}
 
 		for (SvekLine line : bibliotekon.allLines())
@@ -467,10 +467,8 @@ public class DotStringFactory implements Moveable {
 		return idx;
 	}
 
-	public void openCluster(int titleAndAttributeWidth, int titleAndAttributeHeight, TextBlock title, TextBlock stereo,
-			IGroup g) {
-		this.current = current.createChild(titleAndAttributeWidth, titleAndAttributeHeight, title, stereo,
-				colorSequence, skinParam, g);
+	public void openCluster(IGroup g, ClusterHeader clusterHeader) {
+		this.current = current.createChild(clusterHeader, colorSequence, skinParam, g);
 		bibliotekon.addCluster(this.current);
 	}
 
