@@ -37,9 +37,10 @@ package net.sourceforge.plantuml.svek.extremity;
 
 import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.graphic.UDrawable;
+import net.sourceforge.plantuml.ugraphic.UTranslate;
 
 public abstract class Extremity implements UDrawable {
-	
+
 	protected double manageround(double angle) {
 		final double deg = angle * 180.0 / Math.PI;
 		if (isCloseTo(0, deg)) {
@@ -66,11 +67,15 @@ public abstract class Extremity implements UDrawable {
 		}
 		return false;
 	}
-	
+
 	public abstract XPoint2D somePoint();
-	
+
 	public XPoint2D isTooSmallSoGiveThePointCloserToThisOne(XPoint2D pt) {
 		return null;
 	}
 
+	public UTranslate getDeltaForKal() {
+		return new UTranslate();
+	}
+
 }
