@@ -35,8 +35,7 @@
  */
 package net.sourceforge.plantuml.svek.extremity;
 
-import java.awt.geom.Point2D;
-
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.ULine;
 import net.sourceforge.plantuml.ugraphic.UPolygon;
@@ -48,24 +47,24 @@ class ExtremityArrow extends Extremity {
 
 	private UPolygon polygon = new UPolygon();
 	private final ULine line;
-	private final Point2D contact;
+	private final XPoint2D contact;
 
 	@Override
-	public Point2D somePoint() {
+	public XPoint2D somePoint() {
 		return contact;
 	}
 
-	public ExtremityArrow(Point2D p1, double angle, Point2D center) {
+	public ExtremityArrow(XPoint2D p1, double angle, XPoint2D center) {
 		angle = manageround(angle);
 		final int xContact = buildPolygon();
 		polygon.rotate(angle + Math.PI / 2);
 		polygon = polygon.translate(p1.getX(), p1.getY());
-		contact = new Point2D.Double(p1.getX() - xContact * Math.cos(angle + Math.PI / 2),
+		contact = new XPoint2D(p1.getX() - xContact * Math.cos(angle + Math.PI / 2),
 				p1.getY() - xContact * Math.sin(angle + Math.PI / 2));
 		this.line = new ULine(center.getX() - contact.getX(), center.getY() - contact.getY());
 	}
 
-	public ExtremityArrow(Point2D p0, double angle) {
+	public ExtremityArrow(XPoint2D p0, double angle) {
 		this.line = null;
 		angle = manageround(angle);
 		buildPolygon();
