@@ -35,21 +35,21 @@
  */
 package net.sourceforge.plantuml.svek.extremity;
 
-import java.awt.geom.Point2D;
-
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.graphic.UDrawable;
 import net.sourceforge.plantuml.svek.AbstractExtremityFactory;
 import net.sourceforge.plantuml.svek.Side;
 
 public class ExtremityFactoryCrowfoot extends AbstractExtremityFactory implements ExtremityFactory {
 
-	public UDrawable createUDrawable(Point2D p0, Point2D p1, Point2D p2, Side side) {
+	@Override
+	public UDrawable createUDrawable(XPoint2D p0, XPoint2D p1, XPoint2D p2, Side side) {
 		final double ortho = atan2(p0, p2);
 		return new ExtremityCrowfoot(p1, ortho, side);
 	}
 
 	@Override
-	public UDrawable createUDrawable(Point2D p0, double angle, Side side) {
+	public UDrawable createUDrawable(XPoint2D p0, double angle, Side side) {
 		angle -= Math.PI / 2;
 		return new ExtremityCrowfoot(p0, angle, side);
 	}
