@@ -82,8 +82,7 @@ public class Highlight {
 	private HColor getBackColor() {
 		final HColor result = colors.getColor(ColorType.BACK);
 		if (result == null) 
-			return getStyle().value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
-					skinParam.getIHtmlColorSet());
+			return getStyle().value(PName.BackGroundColor).asColor(skinParam.getIHtmlColorSet());
 		
 		return result;
 	}
@@ -91,7 +90,7 @@ public class Highlight {
 	private HColor getLineColor() {
 		final HColor result = colors.getColor(ColorType.LINE);
 		if (result == null) 
-			return getStyle().value(PName.LineColor).asColor(skinParam.getThemeStyle(), skinParam.getIHtmlColorSet());
+			return getStyle().value(PName.LineColor).asColor(skinParam.getIHtmlColorSet());
 		
 		return result;
 	}
