@@ -34,9 +34,9 @@
  */
 package net.sourceforge.plantuml.ugraphic.hand;
 
-import java.awt.geom.Point2D;
 import java.util.Random;
 
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.ugraphic.Shadowable;
 import net.sourceforge.plantuml.ugraphic.UEllipse;
 import net.sourceforge.plantuml.ugraphic.UPolygon;
@@ -66,13 +66,13 @@ public class UEllipseHand {
 				final double variation = 1 + (randomMe() - 0.5) / 8;
 				final double x = width / 2 + Math.cos(angle) * width * variation / 2;
 				final double y = height / 2 + Math.sin(angle) * height * variation / 2;
-				// final Point2D.Double p = new Point2D.Double(x, y);
+				// final XPoint2D p = new XPoint2D(x, y);
 				((UPolygon) poly).addPoint(x, y);
 			}
 		} else {
 			while (angle < Math.PI * 2) {
 				angle += Math.PI / 20;
-				final Point2D pt = getPoint(width, height, angle);
+				final XPoint2D pt = getPoint(width, height, angle);
 				((UPolygon) poly).addPoint(pt.getX(), pt.getY());
 			}
 
@@ -81,11 +81,11 @@ public class UEllipseHand {
 		this.poly.setDeltaShadow(source.getDeltaShadow());
 	}
 
-	private Point2D getPoint(double width, double height, double angle) {
+	private XPoint2D getPoint(double width, double height, double angle) {
 		final double x = width / 2 + Math.cos(angle) * width / 2;
 		final double y = height / 2 + Math.sin(angle) * height / 2;
 		final double variation = (randomMe() - 0.5) / 50;
-		return new Point2D.Double(x + variation * width, y + variation * height);
+		return new XPoint2D(x + variation * width, y + variation * height);
 
 	}
 
