@@ -34,10 +34,10 @@
  */
 package net.sourceforge.plantuml.ugraphic.hand;
 
-import java.awt.geom.CubicCurve2D;
-import java.awt.geom.Point2D;
 import java.util.Random;
 
+import net.sourceforge.plantuml.awt.geom.XCubicCurve2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.ugraphic.UPath;
 import net.sourceforge.plantuml.ugraphic.USegment;
 import net.sourceforge.plantuml.ugraphic.USegmentType;
@@ -51,7 +51,7 @@ public class UPathHand {
 
 		final UPath result = new UPath();
 
-		Point2D last = new Point2D.Double();
+		XPoint2D last = new XPoint2D();
 
 		for (USegment segment : source) {
 			final USegmentType type = segment.getSegmentType();
@@ -59,17 +59,17 @@ public class UPathHand {
 				final double x = segment.getCoord()[0];
 				final double y = segment.getCoord()[1];
 				result.moveTo(x, y);
-				last = new Point2D.Double(x, y);
+				last = new XPoint2D(x, y);
 			} else if (type == USegmentType.SEG_CUBICTO) {
 				final double x2 = segment.getCoord()[4];
 				final double y2 = segment.getCoord()[5];
 				final HandJiggle jiggle = HandJiggle.create(last, 2.0, rnd);
 
-				final CubicCurve2D tmp = new CubicCurve2D.Double(last.getX(), last.getY(), segment.getCoord()[0],
+				final XCubicCurve2D tmp = new XCubicCurve2D(last.getX(), last.getY(), segment.getCoord()[0],
 						segment.getCoord()[1], segment.getCoord()[2], segment.getCoord()[3], x2, y2);
 				jiggle.curveTo(tmp);
 				jiggle.appendTo(result);
-				last = new Point2D.Double(x2, y2);
+				last = new XPoint2D(x2, y2);
 			} else if (type == USegmentType.SEG_LINETO) {
 				final double x = segment.getCoord()[0];
 				final double y = segment.getCoord()[1];
@@ -79,12 +79,12 @@ public class UPathHand {
 					if (seg2.getSegmentType() == USegmentType.SEG_LINETO)
 						result.lineTo(seg2.getCoord()[0], seg2.getCoord()[1]);
 
-				last = new Point2D.Double(x, y);
+				last = new XPoint2D(x, y);
 			} else if (type == USegmentType.SEG_ARCTO) {
 				final double x = segment.getCoord()[5];
 				final double y = segment.getCoord()[6];
 				result.lineTo(x, y);
-				last = new Point2D.Double(x, y);
+				last = new XPoint2D(x, y);
 			} else {
 				this.path = source;
 				return;
