@@ -35,11 +35,10 @@
  */
 package net.sourceforge.plantuml.wbs;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
-import java.awt.geom.Point2D;
-
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.activitydiagram3.ftile.vertical.FtileBoxOld;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.creole.CreoleMode;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.AbstractTextBlock;
@@ -59,13 +58,13 @@ class ITFLeaf extends AbstractTextBlock implements ITF {
 			this.box = FtileBoxOld.createWbs(style, skinParam, label);
 		} else {
 			final TextBlock text = label.create0(
-					style.getFontConfiguration(skinParam.getThemeStyle(), skinParam.getIHtmlColorSet()),
+					style.getFontConfiguration(skinParam.getIHtmlColorSet()),
 					style.getHorizontalAlignment(), skinParam, style.wrapWidth(), CreoleMode.FULL, null, null);
 			this.box = TextBlockUtils.withMargin(text, 0, 3, 1, 1);
 		}
 	}
 
-	public Dimension2D calculateDimension(StringBounder stringBounder) {
+	public XDimension2D calculateDimension(StringBounder stringBounder) {
 		return box.calculateDimension(stringBounder);
 	}
 
@@ -73,24 +72,24 @@ class ITFLeaf extends AbstractTextBlock implements ITF {
 		box.drawU(ug);
 	}
 
-	public Point2D getT1(StringBounder stringBounder) {
-		final Dimension2D dim = calculateDimension(stringBounder);
-		return new Point2D.Double(dim.getWidth() / 2, 0);
+	public XPoint2D getT1(StringBounder stringBounder) {
+		final XDimension2D dim = calculateDimension(stringBounder);
+		return new XPoint2D(dim.getWidth() / 2, 0);
 	}
 
-	public Point2D getT2(StringBounder stringBounder) {
-		final Dimension2D dim = calculateDimension(stringBounder);
-		return new Point2D.Double(dim.getWidth() / 2, dim.getHeight());
+	public XPoint2D getT2(StringBounder stringBounder) {
+		final XDimension2D dim = calculateDimension(stringBounder);
+		return new XPoint2D(dim.getWidth() / 2, dim.getHeight());
 	}
 
-	public Point2D getF1(StringBounder stringBounder) {
-		final Dimension2D dim = calculateDimension(stringBounder);
-		return new Point2D.Double(0, dim.getHeight() / 2);
+	public XPoint2D getF1(StringBounder stringBounder) {
+		final XDimension2D dim = calculateDimension(stringBounder);
+		return new XPoint2D(0, dim.getHeight() / 2);
 	}
 
-	public Point2D getF2(StringBounder stringBounder) {
-		final Dimension2D dim = calculateDimension(stringBounder);
-		return new Point2D.Double(dim.getWidth(), dim.getHeight() / 2);
+	public XPoint2D getF2(StringBounder stringBounder) {
+		final XDimension2D dim = calculateDimension(stringBounder);
+		return new XPoint2D(dim.getWidth(), dim.getHeight() / 2);
 	}
 
 }
